#include <gtk/gtk.h>

GtkWidget *document_new (void);

void
open_action_callback (GtkWidget *widget, gpointer *data)
{
	GtkNotebook *notebook = GTK_NOTEBOOK (data);
	GtkWidget *child = document_new ();
	gint page_num;

	gtk_widget_show (child);
	gtk_notebook_append_page (notebook, child, NULL);
	page_num = gtk_notebook_page_num (notebook, child);
	gtk_notebook_set_current_page (notebook, page_num);
}

void
close_action_callback (GtkWidget *widget, gpointer *data)
{
	GtkNotebook *notebook = GTK_NOTEBOOK (data);
	gint page_num;
	page_num = gtk_notebook_get_current_page (notebook);
	gtk_notebook_remove_page (notebook, page_num);

}

void
exit_action_callback (void)
{
	gtk_main_quit ();
}

void
about_action_callback (void)
{
	const gchar* authors[] = { "Claudio Saavedra", 
				   "James Hacker",
				   NULL};

	const gchar* documenters[] = {"Jimmie Documenter",
				      NULL};

	GtkWidget *about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
					 "name", "Ejemplillo de GTK+", 
					 "version", "0.0.1",
					 "copyright", "(C) 2006 Claudio Saavedra",
					 "comments", "El ejemplo más idiota de GTK+",
					 "authors", authors,
					 "documenters", documenters,
/* 					 "translator-credits", _("translator-credits"), */
/* 					 "logo", logo, */
					 NULL);

	gtk_widget_show (about);

}

void
zoom_out_action_callback (void)
{
}

GtkWidget *
document_new (void)
{
	GtkWidget *text_buffer = gtk_text_view_new ();
	return text_buffer;
}

static const GtkActionEntry entries[] = {
  { "FileMenu", NULL, "_File" },
  { "HelpMenu", NULL, "_Help" },
  { "Open", GTK_STOCK_OPEN, NULL, NULL, NULL, G_CALLBACK (open_action_callback) },
  { "Close", GTK_STOCK_CLOSE, NULL, NULL, NULL, G_CALLBACK (close_action_callback) },
  { "Exit", GTK_STOCK_QUIT, "E_xit", "<control>Q", "Exit the program", exit_action_callback },
  { "About", GTK_STOCK_ABOUT, NULL, NULL, NULL, about_action_callback }
};

static const char *ui_description =
	"<ui>"
	"  <menubar name='MainMenu'>"
	"    <menu action='FileMenu'>"
	"      <menuitem action='Open'/>"
	"      <menuitem action='Close'/>"
	"      <separator />"
	"      <menuitem action='Exit'/>"
	"    </menu>"
	"    <menu action='HelpMenu'>"
	"      <menuitem action='About'/>"
	"    </menu>"
	"  </menubar>"
	"  <toolbar name='Toolbar'>"
  	"    <toolitem action='Open'/>"
	"  </toolbar>"
	"</ui>";

GtkWidget *
create_main_window (void)
{
	GtkWidget *window;
	GtkWidget *vbox;
	GtkWidget *menubar;
	GtkActionGroup *action_group;
	GtkUIManager *ui_manager;
	GtkAccelGroup *accel_group;
	GError *error = NULL;
	GtkWidget *notebook;
	GtkWidget *toolbar;

	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	vbox = gtk_vbox_new (FALSE, 0);
	notebook = gtk_notebook_new ();

	gtk_container_add (GTK_CONTAINER (window), vbox);
	action_group = gtk_action_group_new ("MenuActions");
	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), notebook);

	ui_manager = gtk_ui_manager_new ();
	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);

	accel_group = gtk_ui_manager_get_accel_group (ui_manager);
	gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);

	if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, &error)) {
		g_message ("building menus failed: %s", error->message);
	}

	menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
	gtk_box_pack_start (GTK_BOX (vbox),  menubar, FALSE, FALSE, 0);

	toolbar = gtk_ui_manager_get_widget (ui_manager, "/Toolbar");
	gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);

	gtk_box_pack_start (GTK_BOX (vbox),  notebook, TRUE, TRUE, 0);

	return window;
}

int
main (gint argc, gchar **argv)
{
	GtkWidget *window;
	gtk_init (&argc, &argv);

	window = create_main_window ();
	gtk_window_set_default_size (GTK_WINDOW (window), 400, 300);
	
	gtk_widget_show_all (window);

	g_signal_connect (G_OBJECT (window), "delete-event", 
			  gtk_main_quit, NULL);
	gtk_main ();

	return 0;
}
